XScale support (Gateway 7001), take two

SVN-Revision: 3665
This commit is contained in:
Imre Kaloz 2006-04-17 18:03:53 +00:00
parent f15a435efa
commit b2f8def158
7 changed files with 154 additions and 297 deletions

View file

@ -1,7 +1,7 @@
config BR2_PACKAGE_KMOD_MADWIFI
prompt "kmod-madwifi...................... Atheros Wifi driver"
tristate
default y if BR2_LINUX_2_6_BRCM || BR2_LINUX_2_6_ARUBA || BR2_LINUX_2_4_AR531X
default y if BR2_LINUX_2_6_BRCM || BR2_LINUX_2_6_ARUBA || BR2_LINUX_2_4_AR531X || BR2_LINUX_2_6_XSCALE
default m if CONFIG_DEVEL
default n
help

View file

@ -23,6 +23,9 @@ endif
ifeq ($(ARCH),i386)
HAL_TARGET:=i386-elf
endif
ifeq ($(ARCH),armeb)
HAL_TARGET:=xscale-be-elf
endif
BUS := PCI

View file

@ -30,3 +30,14 @@ diff -ru madwifi-ng-r1486-20060329/hal/public/mips-le-elf.inc madwifi-ng-r1486-2
-COPTS+= -G 0 -EL -mno-abicalls -fno-pic -Wa,--trap \
+COPTS+= -G 0 -EL -mno-abicalls -fno-pic -Wa,--trap -mips32 \
-fno-strict-aliasing -fno-common -fomit-frame-pointer -mlong-calls
diff -ur madwifi-ng-r1486-20060329/hal/public/xscale-be-elf.inc madwifi-ng-r1486-20060329-patch/hal/public/xscale-be-elf.inc
--- madwifi-ng-r1486-20060329/hal/public/xscale-be-elf.inc 2006-02-11 13:04:39.000000000 +0100
+++ madwifi-ng-r1486-20060329-patch/hal/public/xscale-be-elf.inc 2006-04-16 15:07:59.000000000 +0200
@@ -72,5 +72,5 @@
LDOPTS= -EB
COPTS+= -DAH_BYTE_ORDER=AH_BIG_ENDIAN -DAH_REGOPS_FUNC
-COPTS+= -march=armv4 -mbig-endian -fno-strict-aliasing -fno-common -mapcs-32 \
- -mtune=xscale -mshort-load-bytes -msoft-float -mfp=2
+COPTS+= -mcpu=xscale -mbig-endian -fno-strict-aliasing -fno-common \
+ -msoft-float -mfp=2

View file

@ -1,7 +1,7 @@
#
# Automatically generated make config: don't edit
# Linux kernel version: 2.6.16.4
# Fri Apr 14 11:36:42 2006
# Mon Apr 17 16:00:49 2006
#
CONFIG_ARM=y
CONFIG_MMU=y
@ -55,7 +55,8 @@ CONFIG_OBSOLETE_INTERMODULE=y
# Loadable module support
#
CONFIG_MODULES=y
# CONFIG_MODULE_UNLOAD is not set
CONFIG_MODULE_UNLOAD=y
# CONFIG_MODULE_FORCE_UNLOAD is not set
CONFIG_OBSOLETE_MODPARM=y
# CONFIG_MODVERSIONS is not set
# CONFIG_MODULE_SRCVERSION_ALL is not set
@ -180,7 +181,7 @@ CONFIG_ALIGNMENT_TRAP=y
#
CONFIG_ZBOOT_ROM_TEXT=0x0
CONFIG_ZBOOT_ROM_BSS=0x0
CONFIG_CMDLINE="console=ttyS0,115200"
CONFIG_CMDLINE="root=/dev/mtdblock2 rootfstype=jffs2 init=/etc/preinit noinitrd console=ttyS0,115200"
# CONFIG_XIP_KERNEL is not set
#
@ -225,15 +226,10 @@ CONFIG_XFRM=y
# CONFIG_NET_KEY is not set
CONFIG_INET=y
CONFIG_IP_MULTICAST=y
CONFIG_IP_ADVANCED_ROUTER=y
CONFIG_ASK_IP_FIB_HASH=y
# CONFIG_IP_ADVANCED_ROUTER is not set
# CONFIG_ASK_IP_FIB_HASH is not set
# CONFIG_IP_FIB_TRIE is not set
CONFIG_IP_FIB_HASH=y
CONFIG_IP_MULTIPLE_TABLES=y
CONFIG_IP_ROUTE_FWMARK=y
CONFIG_IP_ROUTE_MULTIPATH=y
# CONFIG_IP_ROUTE_MULTIPATH_CACHED is not set
# CONFIG_IP_ROUTE_VERBOSE is not set
# CONFIG_IP_PNP is not set
# CONFIG_NET_IPIP is not set
CONFIG_NET_IPGRE=m
@ -255,13 +251,13 @@ CONFIG_TCP_CONG_ADVANCED=y
#
# TCP congestion control
#
CONFIG_TCP_CONG_BIC=y
CONFIG_TCP_CONG_BIC=m
CONFIG_TCP_CONG_CUBIC=m
CONFIG_TCP_CONG_WESTWOOD=m
CONFIG_TCP_CONG_WESTWOOD=y
CONFIG_TCP_CONG_HTCP=m
# CONFIG_TCP_CONG_HSTCP is not set
# CONFIG_TCP_CONG_HYBLA is not set
CONFIG_TCP_CONG_VEGAS=y
CONFIG_TCP_CONG_VEGAS=m
# CONFIG_TCP_CONG_SCALABLE is not set
#
@ -292,7 +288,7 @@ CONFIG_NETFILTER_XT_TARGET_MARK=m
# CONFIG_NETFILTER_XT_TARGET_NFQUEUE is not set
# CONFIG_NETFILTER_XT_MATCH_COMMENT is not set
# CONFIG_NETFILTER_XT_MATCH_CONNBYTES is not set
# CONFIG_NETFILTER_XT_MATCH_CONNMARK is not set
CONFIG_NETFILTER_XT_MATCH_CONNMARK=y
CONFIG_NETFILTER_XT_MATCH_CONNTRACK=m
# CONFIG_NETFILTER_XT_MATCH_DCCP is not set
CONFIG_NETFILTER_XT_MATCH_HELPER=m
@ -346,7 +342,7 @@ CONFIG_IP_NF_TARGET_REJECT=y
CONFIG_IP_NF_TARGET_IMQ=m
# CONFIG_IP_NF_TARGET_LOG is not set
# CONFIG_IP_NF_TARGET_ULOG is not set
# CONFIG_IP_NF_TARGET_TCPMSS is not set
CONFIG_IP_NF_TARGET_TCPMSS=y
CONFIG_IP_NF_NAT=y
CONFIG_IP_NF_NAT_NEEDED=y
CONFIG_IP_NF_TARGET_MASQUERADE=y

View file

@ -1,43 +1,32 @@
diff -Nur linux-2.6.16.4/arch/arm/mach-ixp4xx/Kconfig linux-2.6.16.4-owrt/arch/arm/mach-ixp4xx/Kconfig
--- linux-2.6.16.4/arch/arm/mach-ixp4xx/Kconfig 2006-04-11 19:19:28.000000000 +0200
+++ linux-2.6.16.4-owrt/arch/arm/mach-ixp4xx/Kconfig 2006-04-12 16:47:34.000000000 +0200
@@ -30,6 +30,13 @@
Engineering Coyote Gateway Reference Platform. For more
information on this platform, see <file:Documentation/arm/IXP4xx>.
diff -Nur linux-2.6.16.4/arch/arm/boot/compressed/head-xscale.S linux-2.6.16.4-owrt/arch/arm/boot/compressed/head-xscale.S
--- linux-2.6.16.4/arch/arm/boot/compressed/head-xscale.S 2006-04-11 19:19:28.000000000 +0200
+++ linux-2.6.16.4-owrt/arch/arm/boot/compressed/head-xscale.S 2006-04-16 16:51:05.000000000 +0200
@@ -47,6 +47,11 @@
orr r7, r7, #(MACH_TYPE_GTWX5715 & 0xff00)
#endif
+config MACH_GATEWAY7001
+ bool "Gateway 7001"
+ help
+ Say 'Y' here if you want your kernel to support Gateway's
+ 7001 Access Point. For more information on this platform,
+ see http://openwrt.org
+#ifdef CONFIG_MACH_GATEWAY7001
+ mov r7, #(MACH_TYPE_GATEWAY7001 & 0xff)
+ orr r7, r7, #(MACH_TYPE_GATEWAY7001 & 0xff00)
+#endif
+
config ARCH_IXDP425
bool "IXDP425"
help
diff -Nur linux-2.6.16.4/arch/arm/mach-ixp4xx/Makefile linux-2.6.16.4-owrt/arch/arm/mach-ixp4xx/Makefile
--- linux-2.6.16.4/arch/arm/mach-ixp4xx/Makefile 2006-04-11 19:19:28.000000000 +0200
+++ linux-2.6.16.4-owrt/arch/arm/mach-ixp4xx/Makefile 2006-04-12 22:34:09.000000000 +0200
@@ -10,4 +10,5 @@
obj-$(CONFIG_MACH_GTWX5715) += gtwx5715-pci.o gtwx5715-setup.o
obj-$(CONFIG_MACH_NSLU2) += nslu2-pci.o nslu2-setup.o nslu2-power.o
obj-$(CONFIG_MACH_NAS100D) += nas100d-pci.o nas100d-setup.o nas100d-power.o
+obj-$(CONFIG_MACH_GATEWAY7001) += gateway7001-pci.o gateway7001-setup.o
#ifdef CONFIG_ARCH_IXP2000
mov r1, #-1
mov r0, #0xd6000000
diff -Nur linux-2.6.16.4/arch/arm/mach-ixp4xx/gateway7001-pci.c linux-2.6.16.4-owrt/arch/arm/mach-ixp4xx/gateway7001-pci.c
--- linux-2.6.16.4/arch/arm/mach-ixp4xx/gateway7001-pci.c 1970-01-01 01:00:00.000000000 +0100
+++ linux-2.6.16.4-owrt/arch/arm/mach-ixp4xx/gateway7001-pci.c 2006-04-12 22:35:29.000000000 +0200
@@ -0,0 +1,77 @@
+++ linux-2.6.16.4-owrt/arch/arm/mach-ixp4xx/gateway7001-pci.c 2006-04-17 19:21:55.000000000 +0200
@@ -0,0 +1,67 @@
+/*
+ * arch/arm/mach-ixp4xx/gateway7001-pci.c
+ * arch/arch/mach-ixp4xx/gateway7001-pci.c
+ *
+ * Gateway 7001 board-level PCI initialization
+ * PCI setup routines for Gateway 7001
+ *
+ * Copyright (c) 2006 Imre Kaloz <kaloz@openwrt.org>
+ * Copyright (C) 2006 Imre Kaloz <kaloz@openwrt.org>
+ *
+ * based on ixdp425-pci.c:
+ * Copyright (C) 2002 Intel Corporation.
+ * Copyright (C) 2003-2004 MontaVista Software, Inc.
+ * based on coyote-pci.c:
+ * Copyright (C) 2002 Jungo Software Technologies.
+ * Copyright (C) 2003 MontaVista Softwrae, Inc.
+ *
+ * Maintainer: Imre Kaloz <kaloz@openwrt.org>
+ *
@ -48,43 +37,34 @@ diff -Nur linux-2.6.16.4/arch/arm/mach-ixp4xx/gateway7001-pci.c linux-2.6.16.4-o
+ */
+
+#include <linux/kernel.h>
+#include <linux/config.h>
+#include <linux/pci.h>
+#include <linux/init.h>
+#include <linux/delay.h>
+
+#include <asm/mach-types.h>
+#include <asm/hardware.h>
+#include <asm/irq.h>
+
+#include <asm/mach/pci.h>
+#include <asm/irq.h>
+#include <asm/hardware.h>
+#include <asm/mach-types.h>
+
+extern void ixp4xx_pci_preinit(void);
+extern int ixp4xx_setup(int nr, struct pci_sys_data *sys);
+extern struct pci_bus *ixp4xx_scan_bus(int nr, struct pci_sys_data *sys);
+
+void __init gateway7001_pci_preinit(void)
+{
+ set_irq_type(IRQ_GATEWAY7001_PCI_INTA, IRQT_LOW);
+ set_irq_type(IRQ_GATEWAY7001_PCI_INTB, IRQT_LOW);
+ set_irq_type(IRQ_GATEWAY7001_PCI_INTC, IRQT_LOW);
+ set_irq_type(IRQ_GATEWAY7001_PCI_INTD, IRQT_LOW);
+ set_irq_type(IRQ_IXP4XX_GPIO10, IRQT_LOW);
+ set_irq_type(IRQ_IXP4XX_GPIO11, IRQT_LOW);
+
+ ixp4xx_pci_preinit();
+}
+
+static int __init gateway7001_map_irq(struct pci_dev *dev, u8 slot, u8 pin)
+{
+ static int pci_irq_table[GATEWAY7001_PCI_IRQ_LINES] = {
+ IRQ_GATEWAY7001_PCI_INTA,
+ IRQ_GATEWAY7001_PCI_INTB,
+ IRQ_GATEWAY7001_PCI_INTC,
+ IRQ_GATEWAY7001_PCI_INTD
+ };
+
+ int irq = -1;
+
+ if (slot >= 1 && slot <= GATEWAY7001_PCI_MAX_DEV &&
+ pin >= 1 && pin <= GATEWAY7001_PCI_IRQ_LINES) {
+ irq = pci_irq_table[(slot + pin - 2) % 4];
+ }
+
+ return irq;
+ if (slot == 0)
+ return IRQ_IXP4XX_GPIO10;
+ else if (slot == 1)
+ return IRQ_IXP4XX_GPIO11;
+ else return -1;
+}
+
+struct hw_pci gateway7001_pci __initdata = {
@ -104,134 +84,63 @@ diff -Nur linux-2.6.16.4/arch/arm/mach-ixp4xx/gateway7001-pci.c linux-2.6.16.4-o
+}
+
+subsys_initcall(gateway7001_pci_init);
diff -Nur linux-2.6.16.4/arch/arm/mach-ixp4xx/Kconfig linux-2.6.16.4-owrt/arch/arm/mach-ixp4xx/Kconfig
--- linux-2.6.16.4/arch/arm/mach-ixp4xx/Kconfig 2006-04-11 19:19:28.000000000 +0200
+++ linux-2.6.16.4-owrt/arch/arm/mach-ixp4xx/Kconfig 2006-04-16 15:58:37.000000000 +0200
@@ -30,6 +30,13 @@
Engineering Coyote Gateway Reference Platform. For more
information on this platform, see <file:Documentation/arm/IXP4xx>.
+config MACH_GATEWAY7001
+ bool "Gateway 7001"
+ help
+ Say 'Y' here if you want your kernel to support Gateway's
+ 7001 Access Point. For more information on this platform,
+ see http://openwrt.org
+
diff -Nur linux-2.6.16.4/arch/arm/mach-ixp4xx/gateway7001-setup.c linux-2.6.16.4-owrt/arch/arm/mach-ixp4xx/gateway7001-setup.c
--- linux-2.6.16.4/arch/arm/mach-ixp4xx/gateway7001-setup.c 1970-01-01 01:00:00.000000000 +0100
+++ linux-2.6.16.4-owrt/arch/arm/mach-ixp4xx/gateway7001-setup.c 2006-04-12 22:45:53.000000000 +0200
@@ -0,0 +1,136 @@
+/*
+ * arch/arm/mach-ixp4xx/gateway7001-setup.c
+ *
+ * Gateway 7001 board-setup
+ *
+ * Copyright (C) 2006 Imre Kaloz <kaloz@openwrt.org>
+ *
+ * based-on ixdp425-setup.c:
+ * Copyright (C) 2003-2005 MontaVista Software, Inc.
+ *
+ * Author: Imre Kaloz <kaloz@openwrt.org>
+ */
+
+#include <linux/kernel.h>
+#include <linux/init.h>
+#include <linux/device.h>
+#include <linux/serial.h>
+#include <linux/tty.h>
+#include <linux/serial_8250.h>
+#include <linux/slab.h>
+
+#include <asm/types.h>
+#include <asm/setup.h>
+#include <asm/memory.h>
+#include <asm/hardware.h>
+#include <asm/mach-types.h>
+#include <asm/irq.h>
+#include <asm/mach/arch.h>
+#include <asm/mach/flash.h>
+
+static struct flash_platform_data gateway7001_flash_data = {
+ .map_name = "cfi_probe",
+ .width = 2,
+};
+
+static struct resource gateway7001_flash_resource = {
+ .flags = IORESOURCE_MEM,
+};
+
+static struct platform_device gateway7001_flash = {
+ .name = "IXP4XX-Flash",
+ .id = 0,
+ .dev = {
+ .platform_data = &gateway7001_flash_data,
+ },
+ .num_resources = 1,
+ .resource = &gateway7001_flash_resource,
+};
+
+static struct ixp4xx_i2c_pins gateway7001_i2c_gpio_pins = {
+ .sda_pin = GATEWAY7001_SDA_PIN,
+ .scl_pin = GATEWAY7001_SCL_PIN,
+};
+
+static struct platform_device gateway7001_i2c_controller = {
+ .name = "IXP4XX-I2C",
+ .id = 0,
+ .dev = {
+ .platform_data = &gateway7001_i2c_gpio_pins,
+ },
+ .num_resources = 0
+};
+
+static struct resource gateway7001_uart_resources[] = {
+ {
+ .start = IXP4XX_UART1_BASE_PHYS,
+ .end = IXP4XX_UART1_BASE_PHYS + 0x0fff,
+ .flags = IORESOURCE_MEM
+ },
+ {
+ .start = IXP4XX_UART2_BASE_PHYS,
+ .end = IXP4XX_UART2_BASE_PHYS + 0x0fff,
+ .flags = IORESOURCE_MEM
+ }
+};
+
+static struct plat_serial8250_port gateway7001_uart_data[] = {
+ {
+ .mapbase = IXP4XX_UART1_BASE_PHYS,
+ .membase = (char *)IXP4XX_UART1_BASE_VIRT + REG_OFFSET,
+ .irq = IRQ_IXP4XX_UART1,
+ .flags = UPF_BOOT_AUTOCONF | UPF_SKIP_TEST,
+ .iotype = UPIO_MEM,
+ .regshift = 2,
+ .uartclk = IXP4XX_UART_XTAL,
+ },
+ {
+ .mapbase = IXP4XX_UART2_BASE_PHYS,
+ .membase = (char *)IXP4XX_UART2_BASE_VIRT + REG_OFFSET,
+ .irq = IRQ_IXP4XX_UART2,
+ .flags = UPF_BOOT_AUTOCONF | UPF_SKIP_TEST,
+ .iotype = UPIO_MEM,
+ .regshift = 2,
+ .uartclk = IXP4XX_UART_XTAL,
+ },
+ { },
+};
+
+static struct platform_device gateway7001_uart = {
+ .name = "serial8250",
+ .id = PLAT8250_DEV_PLATFORM,
+ .dev.platform_data = gateway7001_uart_data,
+ .num_resources = 2,
+ .resource = gateway7001_uart_resources
+};
+
+static struct platform_device *gateway7001_devices[] __initdata = {
+ &gateway7001_i2c_controller,
+ &gateway7001_flash,
+ &gateway7001_uart
+};
+
+static void __init gateway7001_init(void)
+{
+ ixp4xx_sys_init();
+
+ gateway7001_flash_resource.start = IXP4XX_EXP_BUS_BASE(0);
+ gateway7001_flash_resource.end =
+ IXP4XX_EXP_BUS_BASE(0) + ixp4xx_exp_bus_size - 1;
+
+ platform_add_devices(gateway7001_devices, ARRAY_SIZE(gateway7001_devices));
+}
+
config ARCH_IXDP425
bool "IXDP425"
help
diff -Nur linux-2.6.16.4/arch/arm/mach-ixp4xx/Makefile linux-2.6.16.4-owrt/arch/arm/mach-ixp4xx/Makefile
--- linux-2.6.16.4/arch/arm/mach-ixp4xx/Makefile 2006-04-11 19:19:28.000000000 +0200
+++ linux-2.6.16.4-owrt/arch/arm/mach-ixp4xx/Makefile 2006-04-16 16:03:42.000000000 +0200
@@ -10,4 +10,5 @@
obj-$(CONFIG_MACH_GTWX5715) += gtwx5715-pci.o gtwx5715-setup.o
obj-$(CONFIG_MACH_NSLU2) += nslu2-pci.o nslu2-setup.o nslu2-power.o
obj-$(CONFIG_MACH_NAS100D) += nas100d-pci.o nas100d-setup.o nas100d-power.o
+obj-$(CONFIG_MACH_GATEWAY7001) += gateway7001-pci.o coyote-setup.o
diff -Nur linux-2.6.16.4/include/asm-arm/arch-ixp4xx/uncompress.h linux-2.6.16.4-owrt/include/asm-arm/arch-ixp4xx/uncompress.h
--- linux-2.6.16.4/include/asm-arm/arch-ixp4xx/uncompress.h 2006-04-11 19:19:28.000000000 +0200
+++ linux-2.6.16.4-owrt/include/asm-arm/arch-ixp4xx/uncompress.h 2006-04-16 16:25:34.000000000 +0200
@@ -48,7 +48,7 @@
/*
* Coyote and gtwx5715 only have UART2 connected
*/
- if (machine_is_adi_coyote() || machine_is_gtwx5715())
+ if (machine_is_adi_coyote() || machine_is_gtwx5715() || machine_is_gateway7001())
uart_base = (volatile u32*) IXP4XX_UART2_BASE_PHYS;
else
uart_base = (volatile u32*) IXP4XX_UART1_BASE_PHYS;
diff -Nur linux-2.6.16.4/include/asm-arm/arch-ixp4xx/gateway7001.h linux-2.6.16.4-owrt/include/asm-arm/arch-ixp4xx/gateway7001.h
--- linux-2.6.16.4/include/asm-arm/arch-ixp4xx/gateway7001.h 1970-01-01 01:00:00.000000000 +0100
+++ linux-2.6.16.4-owrt/include/asm-arm/arch-ixp4xx/gateway7001.h 2006-04-12 22:34:43.000000000 +0200
@@ -0,0 +1,36 @@
+/*
+ * include/asm-arm/arch-ixp4xx/gateway7001.h
+ *
+ * Gateway 7001 platform specific definitions
+ *
+ * Author: Imre Kaloz <kaloz@openwrt.org>
+ *
+ * Copyright 2006 (c) Imre Kaloz <kaloz@openwrt.org>
+ *
+ * based on ixdp425.h:
+ * Copyright 2004 (c) MontaVista, Software, Inc.
+ *
+ * This file is licensed under the terms of the GNU General Public
+ * License version 2. This program is licensed "as is" without any
+ * warranty of any kind, whether express or implied.
+ */
+
+#ifndef __ASM_ARCH_HARDWARE_H__
+#error "Do not include this directly, instead #include <asm/hardware.h>"
+#endif
+
+#define GATEWAY7001_SDA_PIN 7
+#define GATEWAY7001_SCL_PIN 6
+
+/*
+ * GATEWAY7001 PCI IRQs
+ */
+#define GATEWAY7001_PCI_MAX_DEV 4
+#define GATEWAY7001_PCI_IRQ_LINES 4
+
+
+/* PCI controller GPIO to IRQ pin mappings */
+#define GATEWAY7001_PCI_INTA_PIN 11
+#define GATEWAY7001_PCI_INTB_PIN 10
+#define GATEWAY7001_PCI_INTC_PIN 9
+#define GATEWAY7001_PCI_INTD_PIN 8
diff -Nur linux-2.6.16.4/include/asm-arm/arch-ixp4xx/hardware.h linux-2.6.16.4-owrt/include/asm-arm/arch-ixp4xx/hardware.h
--- linux-2.6.16.4/include/asm-arm/arch-ixp4xx/hardware.h 2006-04-11 19:19:28.000000000 +0200
+++ linux-2.6.16.4-owrt/include/asm-arm/arch-ixp4xx/hardware.h 2006-04-12 22:34:52.000000000 +0200
@@ -46,5 +46,6 @@
#include "prpmc1100.h"
#include "nslu2.h"
#include "nas100d.h"
+#include "gateway7001.h"
#endif /* _ASM_ARCH_HARDWARE_H */
diff -Nur linux-2.6.16.4/include/asm-arm/arch-ixp4xx/irqs.h linux-2.6.16.4-owrt/include/asm-arm/arch-ixp4xx/irqs.h
--- linux-2.6.16.4/include/asm-arm/arch-ixp4xx/irqs.h 2006-04-11 19:19:28.000000000 +0200
+++ linux-2.6.16.4-owrt/include/asm-arm/arch-ixp4xx/irqs.h 2006-04-12 22:35:05.000000000 +0200
@@ -109,4 +109,12 @@
#define IRQ_NAS100D_PCI_INTD IRQ_IXP4XX_GPIO8
#define IRQ_NAS100D_PCI_INTE IRQ_IXP4XX_GPIO7
+/*
+ * GATEWAY7001 board IRQs
+ */
+#define IRQ_GATEWAY7001_PCI_INTA IRQ_IXP4XX_GPIO11
+#define IRQ_GATEWAY7001_PCI_INTB IRQ_IXP4XX_GPIO10
+#define IRQ_GATEWAY7001_PCI_INTC IRQ_IXP4XX_GPIO9
+#define IRQ_GATEWAY7001_PCI_INTD IRQ_IXP4XX_GPIO8
+
#endif
/*
* IXDPG425 is identical to Coyote except for which serial port
* is connected.

View file

@ -10,7 +10,7 @@ if CONFIG_DEVEL
comment "Common Toolchain Options"
endif
if !CONFIG_DEVEL
comment "Using defaults
comment "Using defaults"
endif
config BR2_ENABLE_MULTILIB
@ -42,7 +42,7 @@ config BR2_TARGET_OPTIMIZATION
string "Target Optimizations" if CONFIG_DEVEL
default "-Os -pipe -march=i486 -funit-at-a-time" if BR2_i386
default "-Os -pipe -mips32 -mtune=mips32 -funit-at-a-time" if BR2_mipsel || BR2_mips
default "-Os -pipe -mcpu=xscale -funit-at-a-time" if BR2_armeb
default "-Os -pipe -mcpu=xscale -mno-thumb-interwork -mno-thumb -funit-at-a-time" if BR2_armeb
default "-Os -pipe -funit-at-a-time"
help
Optimizations to use when building for the target host.

View file

@ -45,7 +45,8 @@ ARCH_BIG_ENDIAN=y
# ARCH_HAS_NO_MMU is not set
ARCH_HAS_MMU=y
UCLIBC_HAS_FLOATS=y
HAS_FPU=y
# HAS_FPU is not set
UCLIBC_HAS_SOFT_FLOAT=y
# DO_C99_MATH is not set
KERNEL_SOURCE="./toolchain_build_armeb/linux"
C_SYMBOL_PREFIX=""
diff -Nur linux-2.6.16.4/arch/arm/mach-ixp4xx/coyote-setup.c linux-2.6.16.4-owrt/arch/arm/mach-ixp4xx/coyote-setup.c
--- linux-2.6.16.4/arch/arm/mach-ixp4xx/coyote-setup.c 2006-04-11 19:19:28.000000000 +0200
+++ linux-2.6.16.4-owrt/arch/arm/mach-ixp4xx/coyote-setup.c 2006-04-16 16:03:23.000000000 +0200
@@ -1,9 +1,10 @@
/*
* arch/arm/mach-ixp4xx/coyote-setup.c
*
* Board setup for ADI Engineering and IXDGP425 boards
*
* Copyright (C) 2003-2005 MontaVista Software, Inc.
+ * Copyright (C) 2006 Imre Kaloz <Kaloz@openwrt.org>
*
* Author: Deepak Saxena <dsaxena@plexity.net>
*/
@@ -111,6 +112,19 @@
MACHINE_END
#endif
+#ifdef CONFIG_MACH_GATEWAY7001
+MACHINE_START(GATEWAY7001, "Gateway 7001")
+ /* Maintainer: Imre Kaloz <kaloz@openwrt.org> */
@ -241,73 +150,10 @@ diff -Nur linux-2.6.16.4/arch/arm/mach-ixp4xx/gateway7001-setup.c linux-2.6.16.4
+ .init_irq = ixp4xx_init_irq,
+ .timer = &ixp4xx_timer,
+ .boot_params = 0x0100,
+ .init_machine = gateway7001_init,
+ .init_machine = coyote_init,
+MACHINE_END
+#endif
+
@@ -1,9 +1,10 @@
* arch/arm/mach-ixp4xx/coyote-setup.c
*
- * Board setup for ADI Engineering and IXDGP425 boards
+ * Board setup for ADI Engineering, IXDGP425 and Gateway 7001 boards
*
* Copyright (C) 2003-2005 MontaVista Software, Inc.